==> generic-plugin-5.0.2-sources.jar: com/xebialabs/deployit/plugin/generic/step/ArtifactDeleteStep.java <==
package com.xebialabs.deployit.plugin.generic.step;

import java.util.Set;
import com.google.common.base.Strings;

import com.xebialabs.deployit.plugin.api.flow.StepExitCode;
import com.xebialabs.deployit.plugin.api.udm.DeployableArtifact;
import com.xebialabs.deployit.plugin.overthere.HostContainer;
import com.xebialabs.overthere.OverthereFile;

import static com.google.common.base.Preconditions.checkNotNull;
import static com.google.common.base.Strings.nullToEmpty;
import static com.google.common.collect.Sets.newHashSet;

@SuppressWarnings("serial")
public class ArtifactDeleteStep extends BaseDeploymentStep {

    private String targetDirectory;

    private DeployableArtifact artifact;

    private String targetFile;

    private boolean targetDirectoryShared;

    private boolean targetPathSharedSubDirectories;

    private Set<String> deleteAdditionalTargetFiles = newHashSet();


    public ArtifactDeleteStep(){
    }

    public ArtifactDeleteStep(int order, HostContainer container, DeployableArtifact artifact, String targetDirectory) {
        super(order, container);
        this.artifact = artifact;
        this.targetDirectory = checkNotNull(targetDirectory);
    }

    public ArtifactDeleteStep(int order, HostContainer container, String targetDirectory) {
        this(order, container, null, targetDirectory);
    }

    @Override
    protected StepExitCode doExecute() throws Exception {
        if (artifact != null) {
            deleteArtifact();
        } else {
            deleteTargetFile();
        }

        deleteAdditionalFiles(getDeleteAdditionalTargetFiles());

        return StepExitCode.SUCCESS;
    }

    protected void deleteArtifact() {
        OverthereFile localFile = artifact.getFile();
        OverthereFile remoteDir = getRemoteConnection().getFile(targetDirectory);

        if (localFile.isDirectory()) {
            if (targetDirectoryShared) {
                deleteRemoteDirectory(localFile, remoteDir);
            } else {
                deleteFile(remoteDir);
            }
        } else {
            String name = nullToEmpty(targetFile).trim().isEmpty() ? artifact.getName() : targetFile;
            deleteFile(remoteDir.getFile(name));
        }
    }

    private void deleteRemoteDirectory(final OverthereFile localFile, final OverthereFile remoteDir) {
        for (OverthereFile file : localFile.listFiles()) {
            OverthereFile remoteFile = remoteDir.getFile(file.getName());
            if (targetPathSharedSubDirectories && file.isDirectory()) {
                if (remoteFile.exists()) {
                    deleteRemoteDirectory(file, remoteFile);
                    if (remoteFile.listFiles().isEmpty()) {
                        deleteFile(remoteFile);
                    }
                } else {
                    getCtx().logOutput(remoteFile.getPath() + " does not exist on host " + getContainer().getHost() + ". Will not perform delete.");
                }
            } else {
                deleteFile(remoteFile);
            }
        }
    }

    protected void deleteTargetFile() {
        OverthereFile remoteFile = getRemoteConnection().getFile(targetDirectory);
        if (!nullToEmpty(targetFile).trim().isEmpty()) {
            remoteFile = remoteFile.getFile(targetFile);
        }
        deleteFile(remoteFile);
    }



    protected void deleteAdditionalFiles(Set<String> files) {
        for (String file : files) {
            OverthereFile remoteFile = getRemoteConnection().getFile(file);
            if (remoteFile.exists()) {
                getCtx().logOutput("Deleting " + remoteFile.getPath() + " on host " + getContainer().getHost());
                remoteFile.deleteRecursively();
            } else {
                getCtx().logOutput(remoteFile.getPath() + " does not exist on host " + getContainer().getHost() + ". Will not perform delete.");
            }
        }
    }

    protected void deleteFile(OverthereFile file) {
        getCtx().logOutput("Deleting " + file.getPath() + " on host " + getContainer().getHost());
        if (file.exists()) {
            file.deleteRecursively();
        } else {
            getCtx().logOutput(file.getPath() + " does not exist on host " + getContainer().getHost() + ". Will not perform delete.");
        }

    }

    @Override
    public String getDescription() {
        String description = super.getDescription();
        if (description == null) {
            return generateDescription();
        }
        return description;
    }

    protected String generateDescription() {
        if (artifact != null) {
            return "Delete " + artifact.getName() + " from " + getContainer().getHost();
        }

        if (!Strings.nullToEmpty(targetFile).trim().isEmpty()) {
            return "Delete file " + targetFile + " from directory " + targetDirectory + " on host " +  getContainer().getHost();
        }

        return "Delete directory " + targetDirectory + " from  " + getContainer().getHost();
    }

    public String getTargetFile() {
        return targetFile;
    }

    public void setTargetFile(String targetFile) {
        this.targetFile = targetFile;
    }

    public boolean isTargetDirectoryShared() {
        return targetDirectoryShared;
    }

    public void setTargetDirectoryShared(boolean targetDirectoryShared) {
        this.targetDirectoryShared = targetDirectoryShared;
    }

    public Set<String> getDeleteAdditionalTargetFiles() {
        return deleteAdditionalTargetFiles;
    }

    public void setDeleteAdditionalTargetFiles(Set<String> deleteAdditionalTargetFiles) {
        this.deleteAdditionalTargetFiles = deleteAdditionalTargetFiles;
    }

    public void setTargetPathSharedSubDirectories(final boolean targetPathSharedSubDirectories) {
        this.targetPathSharedSubDirectories = targetPathSharedSubDirectories;
    }

    @Override
    public void setDescription(final String description) {
        super.setDescription(description);
    }
}

==> generic-plugin-23.3.4-sources.jar: com/xebialabs/deployit/plugin/generic/step/ArtifactDeleteStep.java <==
package com.xebialabs.deployit.plugin.generic.step;

import java.util.Objects;
import java.util.Set;
import com.google.common.base.Strings;

import com.xebialabs.deployit.plugin.api.flow.StepExitCode;
import com.xebialabs.deployit.plugin.api.udm.DeployableArtifact;
import com.xebialabs.deployit.plugin.overthere.HostContainer;
import com.xebialabs.overthere.OverthereFile;

import static com.google.common.base.Strings.nullToEmpty;
import static com.google.common.collect.Sets.newHashSet;

@SuppressWarnings("serial")
public class ArtifactDeleteStep extends BaseDeploymentStep {

    private String targetDirectory;

    private DeployableArtifact artifact;

    private String targetFile;

    private boolean targetDirectoryShared;

    private boolean targetPathSharedSubDirectories;

    private Set<String> deleteAdditionalTargetFiles = newHashSet();


    public ArtifactDeleteStep(){
    }

    public ArtifactDeleteStep(int order, HostContainer container, DeployableArtifact artifact, String targetDirectory) {
        super(order, container);
        this.artifact = artifact;
        this.targetDirectory = Objects.requireNonNull(targetDirectory);
    }

    public ArtifactDeleteStep(int order, HostContainer container, String targetDirectory) {
        this(order, container, null, targetDirectory);
    }

    @Override
    protected StepExitCode doExecute() throws Exception {
        if (artifact != null) {
            deleteArtifact();
        } else {
            deleteTargetFile();
        }

        deleteAdditionalFiles(getDeleteAdditionalTargetFiles());

        return StepExitCode.SUCCESS;
    }

    protected void deleteArtifact() {
        OverthereFile localFile = artifact.getFile();
        OverthereFile remoteDir = getRemoteConnection().getFile(targetDirectory);

        if (localFile.isDirectory()) {
            if (targetDirectoryShared) {
                deleteRemoteDirectory(localFile, remoteDir);
            } else {
                deleteFile(remoteDir);
            }
        } else {
            String name = nullToEmpty(targetFile).trim().isEmpty() ? artifact.getName() : targetFile;
            deleteFile(remoteDir.getFile(name));
        }
    }

    private void deleteRemoteDirectory(final OverthereFile localFile, final OverthereFile remoteDir) {
        for (OverthereFile file : localFile.listFiles()) {
            OverthereFile remoteFile = remoteDir.getFile(file.getName());
            if (targetPathSharedSubDirectories && file.isDirectory()) {
                if (remoteFile.exists()) {
                    deleteRemoteDirectory(file, remoteFile);
                    if (remoteFile.listFiles().isEmpty()) {
                        deleteFile(remoteFile);
                    }
                } else {
                    getCtx().logOutput(remoteFile.getPath() + " does not exist on host " + getContainer().getHost() + ". Will not perform delete.");
                }
            } else {
                deleteFile(remoteFile);
            }
        }
    }

    protected void deleteTargetFile() {
        OverthereFile remoteFile = getRemoteConnection().getFile(targetDirectory);
        if (!nullToEmpty(targetFile).trim().isEmpty()) {
            remoteFile = remoteFile.getFile(targetFile);
        }
        deleteFile(remoteFile);
    }



    protected void deleteAdditionalFiles(Set<String> files) {
        for (String file : files) {
            OverthereFile remoteFile = getRemoteConnection().getFile(file);
            if (remoteFile.exists()) {
                getCtx().logOutput("Deleting " + remoteFile.getPath() + " on host " + getContainer().getHost());
                remoteFile.deleteRecursively();
            } else {
                getCtx().logOutput(remoteFile.getPath() + " does not exist on host " + getContainer().getHost() + ". Will not perform delete.");
            }
        }
    }

    protected void deleteFile(OverthereFile file) {
        getCtx().logOutput("Deleting " + file.getPath() + " on host " + getContainer().getHost());
        if (file.exists()) {
            file.deleteRecursively();
        } else {
            getCtx().logOutput(file.getPath() + " does not exist on host " + getContainer().getHost() + ". Will not perform delete.");
        }

    }

    @Override
    public String getDescription() {
        String description = super.getDescription();
        if (description == null) {
            return generateDescription();
        }
        return description;
    }

    protected String generateDescription() {
        if (artifact != null) {
            return "Delete " + artifact.getName() + " from " + getContainer().getHost();
        }

        if (!Strings.nullToEmpty(targetFile).trim().isEmpty()) {
            return "Delete file " + targetFile + " from directory " + targetDirectory + " on host " +  getContainer().getHost();
        }

        return "Delete directory " + targetDirectory + " from  " + getContainer().getHost();
    }

    public String getTargetFile() {
        return targetFile;
    }

    public void setTargetFile(String targetFile) {
        this.targetFile = targetFile;
    }

    public boolean isTargetDirectoryShared() {
        return targetDirectoryShared;
    }

    public void setTargetDirectoryShared(boolean targetDirectoryShared) {
        this.targetDirectoryShared = targetDirectoryShared;
    }

    public Set<String> getDeleteAdditionalTargetFiles() {
        return deleteAdditionalTargetFiles;
    }

    public void setDeleteAdditionalTargetFiles(Set<String> deleteAdditionalTargetFiles) {
        this.deleteAdditionalTargetFiles = deleteAdditionalTargetFiles;
    }

    public void setTargetPathSharedSubDirectories(final boolean targetPathSharedSubDirectories) {
        this.targetPathSharedSubDirectories = targetPathSharedSubDirectories;
    }
}
